@@ -4,16 +4,23 @@
 #'
 #' @param json_link A Socrata dataset JSON endpoint URL (e.g., "https://data.cityofnewyork.us/resource/abcd-1234.json").
 #' @param limit Number of rows to retrieve (default = 10,000).
+#' @param timeout_sec Request timeout in seconds (default = 30).
 #' @return A tibble containing the requested dataset.
 #'
 #' @examples
-#' \dontrun{
-#' endpoint <- "https://data.cityofnewyork.us/resource/erm2-nwe9.json"
-#' small_sample <- nyc_any_dataset(endpoint, limit = 10)
-#' head(small_sample)
+#' # Examples that hit the live NYC Open Data API are wrapped so CRAN checks
+#' # do not fail when the network is unavailable or slow.
+#' \donttest{
+#' if (curl::has_internet()) {
+#'   endpoint <- "https://data.cityofnewyork.us/resource/erm2-nwe9.json"
+#'   out <- try(nyc_any_dataset(endpoint, limit = 3), silent = TRUE)
+#'   if (!inherits(out, "try-error")) {
+#'     head(out)
+#'   }
+#' }
 #' }
 #' @export
-nyc_any_dataset <- function(json_link, limit = 10000) {
+nyc_any_dataset <- function(json_link, limit = 10000, timeout_sec = 30) {
   if (!is.character(json_link) || length(json_link) != 1 || is.na(json_link)) {
     stop("`json_link` must be a single, non-missing character URL.", call. = FALSE)
   }
@@ -23,8 +30,6 @@ nyc_any_dataset <- function(json_link, limit = 10000) {
 
   query_list <- list("$limit" = as.integer(limit))
 
-  resp <- httr::GET(json_link, query = query_list)
-  httr::stop_for_status(resp)
-  data <- jsonlite::fromJSON(httr::content(resp, as = "text"), flatten = TRUE)
+  data <- .nyc_get_json(json_link, query_list, timeout_sec = timeout_sec)
   tibble::as_tibble(data)
 }
